<?php
class Thb_Theme_Admin {
	/**
	 *  Main instance
	 */
	private static $_instance;

	/**
	 *  Theme Name
	 */
	public static $thb_theme_name;

	/**
	 *  Theme Version
	 */
	public static $thb_theme_version;

	/**
	 *  Theme Slug
	 */
	public static $thb_theme_slug;

	/**
	 *  Theme Directory
	 */
	public static $thb_theme_directory;

	/**
	 *  Theme Directory URL
	 */
	public static $thb_theme_directory_uri;

	/**
	 *  Product Key
	 */
	public static $thb_product_key;

	/**
	 *  Product Key Expiration
	 */
	public static $thb_product_key_expired;

	/**
	 *  Theme Constructor executed only once per request
	 */
	public function __construct() {
		if ( self::$_instance ) {
			_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
		}
	}

	/**
	 * You cannot clone this class
	 */
	public function __clone() {
		_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
	}

	/**
	 * You cannot unserialize instances of this class
	 */
	public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
	}

	public static function instance() {
		global $thb_Theme_Admin;
		if ( ! self::$_instance ) {
			self::$_instance = new self();
			$thb_Theme_Admin = self::$_instance;

			// Theme Variables
			$theme                         = wp_get_theme();
			self::$thb_theme_name          = $theme->get( 'Name' );
			self::$thb_theme_version       = $theme->parent() ? $theme->parent()->get( 'Version' ) : $theme->get( 'Version' );
			self::$thb_theme_slug          = $theme->template;
			self::$thb_theme_directory     = get_template_directory() . '/';
			self::$thb_theme_directory_uri = get_template_directory_uri() . '/';

			self::$thb_product_key         = get_option( 'thb_' . self::$thb_theme_slug . '_key' );
			self::$thb_product_key_expired = get_option( 'thb_' . self::$thb_theme_slug . '_key_expired' );

			// After Setup Theme
			add_action( 'after_setup_theme', array( self::$_instance, 'afterSetupTheme' ) );

			// Setup Admin Menus
			if ( is_admin() ) {
				self::$_instance->initAdminPages();
			}
		}

		return self::$_instance;
	}
	/**
	 *  After Theme Setup
	 */
	public function afterSetupTheme() {
		/* WooCommerce Support */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-lightbox' );

		/* WooCommerce Products per Page */
		add_filter( 'loop_shop_per_page', 'thb_shops_per_page', 20 );

		function thb_shops_per_page( $products_per_page ) {
			$products_per_page_get = filter_input( INPUT_GET, 'products_per_page', FILTER_VALIDATE_INT );
			$products_per_page     = isset( $products_per_page_get ) ? $products_per_page_get : ot_get_option( 'products_per_page' );
			return $products_per_page;
		}
		/* Gutenberg */
		add_theme_support( 'align-wide' );
		add_theme_support( 'align-full' );
		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => esc_html__( 'Accent Color', 'werkstatt' ),
					'slug'  => 'thb-accent',
					'color' => ot_get_option( 'accent_color', '#ef173b' ),
				),
			)
		);

		/* Post Formats */
		add_theme_support( 'post-formats', array( 'image', 'gallery', 'video', 'link' ) );
		add_post_type_support( 'page', 'excerpt' );

		/* Text Domain */
		load_theme_textdomain( 'werkstatt', get_stylesheet_directory() . '/inc/languages' );

		/* Background Support */
		add_theme_support(
			'custom-background',
			array(
				'default-color'    => 'ffffff',
				'wp-head-callback' => 'thb_change_custom_background_cb',
			)
		);

		/* Title Support */
		add_theme_support( 'title-tag' );

		/* Required Settings */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 1170;
		}
		add_theme_support( 'automatic-feed-links' );

		/* Editor Styling */
		add_editor_style( array( 'assets/css/editor-style.css' ) );

		/* Image Settings */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 80, 75, true );

		$thb_image_sizes = self::$_instance->thb_image_sizes();

		// Register image size
		foreach ( $thb_image_sizes as $image_size ) {
			add_image_size( $image_size['slug'], $image_size['width'], $image_size['height'], $image_size['crop'] );
		}

		if ( false === get_option( 'medium_crop' ) ) {
				add_option( 'medium_crop', '1' );
		} else {
				update_option( 'medium_crop', '1' );
		}

		/* HTML5 Galleries */
		add_theme_support( 'html5', array( 'gallery', 'caption' ) );

		/* Register Menus */
		add_theme_support( 'nav-menus' );
		register_nav_menus(
			array(
				'nav-menu'       => esc_html__( 'Navigation Menu', 'werkstatt' ),
				'secondary-menu' => esc_html__( 'Secondary Menu', 'werkstatt' ),
			)
		);

		$sidebars = ot_get_option( 'sidebars' );
		if ( ! empty( $sidebars ) ) {
			foreach ( $sidebars as $sidebar ) {
				register_sidebar(
					array(
						'name'          => $sidebar['title'],
						'id'            => $sidebar['id'],
						'description'   => '',
						'before_widget' => '<div id="%1$s" class="widget cf %2$s">',
						'after_widget'  => '</div>',
						'before_title'  => '<h6>',
						'after_title'   => '</h6>',
					)
				);
			}
		}
	}
	public function thb_image_sizes() {
		$thb_image_sizes = apply_filters(
			'thb_image_sizes_filter',
			array(
				array(
					'slug'   => 'werkstatt-square',
					'width'  => 160,
					'height' => 150,
					'crop'   => true,
					'triple' => true,
				),
				array(
					'slug'   => 'werkstatt-slider',
					'width'  => 1600,
					'height' => 900,
					'crop'   => true,
					'triple' => false,
				),
				array(
					'slug'   => 'werkstatt-blog',
					'width'  => 320,
					'height' => 200,
					'crop'   => true,
					'triple' => false,
				),
				array(
					'slug'   => 'werkstatt-bloglarge',
					'width'  => 640,
					'height' => 320,
					'crop'   => true,
					'triple' => false,
				),
				array(
					'slug'   => 'werkstatt-masonry',
					'width'  => 640,
					'height' => 9999,
					'crop'   => false,
					'triple' => true,
				),
				array(
					'slug'   => 'werkstatt-squarelarge',
					'width'  => 380,
					'height' => 350,
					'crop'   => true,
					'triple' => true,
				),
				array(
					'slug'   => 'werkstatt-rectangle',
					'width'  => 320,
					'height' => 240,
					'crop'   => true,
					'triple' => true,
				),
				array(
					'slug'   => 'werkstatt-tall',
					'width'  => 380,
					'height' => 700,
					'crop'   => true,
					'triple' => true,
				),
				array(
					'slug'   => 'werkstatt-wide',
					'width'  => 760,
					'height' => 350,
					'crop'   => true,
					'triple' => true,
				),
			)
		);

		function thb_calculate_image_orientation( $thb_image_sizes ) {
			if ( ! is_array( $thb_image_sizes ) ) {
				return;
			}
			$new_sizes = array();
			foreach ( $thb_image_sizes as $image_size ) {
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-small',
					'width'  => absint( $image_size['width'] / 2 ),
					'height' => 9999 === $image_size['height'] ? 9999 : absint( $image_size['height'] * 2 ),
					'crop'   => $image_size['crop'],
				);
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-2x',
					'width'  => $image_size['width'] * 2,
					'height' => 9999 === $image_size['height'] ? 9999 : $image_size['height'] * 2,
					'crop'   => $image_size['crop'],
				);
				if ( true === $image_size['triple'] ) {
					$new_sizes[] = array(
						'slug'   => $image_size['slug'] . '-3x',
						'width'  => $image_size['width'] * 3,
						'height' => 9999 === $image_size['height'] ? 9999 : $image_size['height'] * 3,
						'crop'   => $image_size['crop'],
					);
				}
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-mini',
					'width'  => 20,
					'height' => 9999 === $image_size['height'] ? 9999 : absint( ( $image_size['height'] * 20 ) / $image_size['width'] ),
					'crop'   => $image_size['crop'],
				);
			}
			return $new_sizes;
		}
		$new_sizes = thb_calculate_image_orientation( $thb_image_sizes );
		foreach ( $new_sizes as $new_size ) {
			$thb_image_sizes[] = $new_size;
		}
		return $thb_image_sizes;
	}
	public function thbDemos() {
		return array(
			array(
				'import_file_name' => 'Only Portfolio Pages',
				'import_file_url'  => self::$thb_theme_directory_uri . 'demo-import/just-portfolio/democontent.xml',
				'import_image'     => self::$thb_theme_directory_uri . 'assets/img/admin/demos/just-portfolio.jpg',
			),
			array(
				'import_file_name'         => 'Main',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/main/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/main/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/main/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/masonry1.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/',
			),
			array(
				'import_file_name'         => 'Masonry',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/masonry/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/masonry/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/masonry/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/masonry2.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-masonry/',
			),
			array(
				'import_file_name'         => 'Agency Simple',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/agency-simple/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/agency-simple/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/agency-simple/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/agency_simple.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-agency-simple/',
			),
			array(
				'import_file_name'         => 'Simple Portfolio',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/masonry/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/masonry/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/masonry/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/simple_portfolio.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-masonry/3-columns/',
			),
			array(
				'import_file_name'         => 'Grid',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/main/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/main/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/main/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/grid.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/grid-4-columns/',
			),
			array(
				'import_file_name'         => 'Agency',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/agency/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/agency/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/agency/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/agency.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-agency/',
			),
			array(
				'import_file_name'         => 'Background Grid',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/text-style/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/text-style/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/text-style/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/bg_grid.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-text-style/background-grid/',
			),
			array(
				'import_file_name'         => 'Carousel',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/carousel/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/carousel/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/carousel/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/carousel.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-carousel/',
			),
			array(
				'import_file_name'         => 'Designer',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/designer/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/designer/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/designer/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/designer.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-designer/',
			),
			array(
				'import_file_name'         => 'Freelancer',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/freelancer/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/freelancer/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/freelancer/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/freelancer.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-freelancer/',
			),
			array(
				'import_file_name'         => 'Personal',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/personal/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/personal/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/personal/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/personal.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-personal/',
			),
			array(
				'import_file_name'         => 'Modern Agency',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/agency-modern/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/agency-modern/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/agency-modern/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/agency_modern.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-agency-modern/',
			),
			array(
				'import_file_name'         => 'Text Style',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/text-style/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/text-style/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/text-style/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/text_style.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-text-style/',
			),
			array(
				'import_file_name'         => 'Full Screen Vertical',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/vertical/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/vertical/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/vertical/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_vertical.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen/',
			),
			array(
				'import_file_name'         => 'Full Screen Segments',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/segments/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/segments/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/segments/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_segments.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-segments/',
			),
			array(
				'import_file_name'         => 'Full Screen Parallax',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/parallax/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/parallax/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/parallax/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_parallax.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-parallax/',
			),
			array(
				'import_file_name'         => 'Full Screen Creative',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/creative/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/creative/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/creative/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_creative.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-creative/',
			),
			array(
				'import_file_name'         => 'Full Screen Split',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/split/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/split/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/split/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_split.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-split/',
			),
			array(
				'import_file_name'         => 'Photography',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/photography/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/photography/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/photography/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/photographer.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-photography/',
			),
			array(
				'import_file_name'         => 'Digital Agency',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/agency-digital/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/agency-digital/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/agency-digital/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/digital_agency.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-agency-digital/',
			),
			array(
				'import_file_name'         => 'Architecture',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/architecture/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/architecture/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/architecture/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/architecture.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-architecture/',
			),
			array(
				'import_file_name'         => 'Full Screen Glitch',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/glitch/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/glitch/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/glitch/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/glitch.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-glitch/',
			),
			array(
				'import_file_name'         => 'Full Screen Objects',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/objects/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/objects/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/objects/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/full_screen_objects.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-objects/',
			),
			array(
				'import_file_name'         => 'Developer',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/developer/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/developer/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/developer/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/developer.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-developer/',
			),
			array(
				'import_file_name'         => 'Lateral',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/lateral/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/lateral/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/lateral/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/left_menu.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-lateral/',
			),
			array(
				'import_file_name'         => 'Lateral Dark',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/lateral-dark/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/lateral-dark/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/lateral-dark/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/left_menu_dark.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-lateral-dark/',
			),
			array(
				'import_file_name'         => 'Tasty Landing',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/landing-tasty/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/landing-tasty/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/landing-tasty/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/tasty.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-landing-tasty/',
			),
			array(
				'import_file_name'         => 'Sphere Landing',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/landing-sphere/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/landing-sphere/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/landing-sphere/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/sphere.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-landing-sphere/',
			),
			array(
				'import_file_name'         => 'Boxed',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/boxed/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/boxed/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/boxed/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/boxed.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-boxed/',
			),
			array(
				'import_file_name'         => 'Full Screen Pan',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/pan_bg/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/pan_bg/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/pan_bg/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/pan_bg.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-fullscreen-pan/',
			),
			array(
				'import_file_name'         => 'Carousel Hover',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/carousel-hover/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/carousel-hover/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/carousel-hover/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/root.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-carousel-hover/',
			),
			array(
				'import_file_name'         => 'Rudiger',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/rudiger/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/rudiger/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/rudiger/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/rudiger.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-rudiger/',
			),
			array(
				'import_file_name'         => 'Ninety Three',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/ninetythree/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/ninetythree/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/ninetythree/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/ninetythree.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-ninetythree/',
			),
			array(
				'import_file_name'         => 'DNY',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/dny/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/dny/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/dny/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/dny.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-dny/',
			),
			array(
				'import_file_name'         => 'Collective',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/collective/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/collective/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/collective/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/collective.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-collective/',
			),
			array(
				'import_file_name'         => 'Bold Studio',
				'import_file_url'          => self::$thb_theme_directory_uri . 'demo-import/bold/democontent.xml',
				'import_widget_file_url'   => self::$thb_theme_directory_uri . 'demo-import/bold/widget_data.json',
				'import_theme_options_url' => self::$thb_theme_directory_uri . 'demo-import/bold/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/bold.jpg',
				'import_demo_url'          => 'https://werkstatt.wpthemestudios.com/werkstatt-bold/',
			),
		);
	}
	/**
	 *  Inintialize Admin Pages
	 */
	public function initAdminPages() {
		global $pagenow;

		// Script and styles
		add_action( 'admin_enqueue_scripts', array( & $this, 'adminPageEnqueue' ) );

		// Menu Pages
		add_action( 'admin_menu', array( & $this, 'adminSetupMenu' ), 1 );

		// Theme Options Redirect
		if ( $pagenow ) {
			if ( 'admin.php' === $pagenow && isset( $_GET['page'] ) && 'thb-theme-options' == wp_unslash( $_GET['page'] ) ) {
				if ( ! ( defined( 'WP_CLI' ) && WP_CLI ) ) {
					wp_redirect( admin_url( 'themes.php?page=ot-theme-options' ) );
					die();
				}
			}
		}

		// Redirect to Main Page
		add_action( 'after_switch_theme', array( & $this, 'thb_activation_redirect' ) );

		// Ajax Option Update
		add_action( 'wp_ajax_thb_update_options', array( & $this, 'thb_update_options' ) );
		add_action( 'wp_ajax_nopriv_thb_update_options', array( & $this, 'thb_update_options' ) );

		// Admin Notices
		add_action( 'admin_notices', array( & $this, 'thb_admin_notices' ) );

		// Theme Updates
		add_action( 'admin_init', array( & $this, 'thb_theme_update' ) );

		// Plugin Update Nonce
		add_action( 'register_sidebar', array( & $this, 'thb_theme_admin_init' ) );

	}
	function thb_admin_notices() {
		$remote_ver = get_option( 'thb_' . self::$thb_theme_slug . '_remote_ver' ) ? get_option( 'thb_' . self::$thb_theme_slug . '_remote_ver' ) : self::$thb_theme_version;
		$local_ver  = self::$thb_theme_version;

		if ( version_compare( $local_ver, $remote_ver, '<' ) ) {
			if (
				( ! self::$thb_product_key && ( self::$thb_product_key_expired == 0 ) ) ||
				( self::$thb_product_key && ( self::$thb_product_key_expired == 1 ) )
			) {
				echo '<div class="notice is-dismissible error thb_admin_notices">
				<p>There is an update available for the <strong>' . self::$thb_theme_name . '</strong> theme. Go to <a href="' . esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) . '">Product Registration</a> to enable theme updates.</p>
				</div>';
			}

			if ( ( self::$thb_product_key && ( self::$thb_product_key_expired == 0 ) ) ) {
				echo '<div class="notice is-dismissible error thb_admin_notices">
				<p>There is an update available for the <strong>' . self::$thb_theme_name . '</strong> theme. <a href="' . esc_url( admin_url() ) . 'update-core.php">Update now</a>.</p>
				</div>';
			}
		}
	}
	public function thb_update_options() {
		$key = !empty($_POST['key']) ? sanitize_text_field( $_POST['key'] ) : '';
		$expired = filter_input( INPUT_POST, 'expired', FILTER_VALIDATE_BOOLEAN );

		update_option( 'thb_' . self::$thb_theme_slug . '_key', $key );
		update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', $expired );
		wp_die();
	}
	public function thb_theme_update() {
		add_filter( 'pre_set_site_transient_update_themes', array( & $this, 'thb_check_for_update_theme' ) );
		add_filter( 'upgrader_pre_download', array( $this, 'thb_upgradeFilter' ), 10, 4 );
	}
	public function thb_check_for_update_plugins() {
		$name = 'thb_' . self::$thb_theme_slug . '_plugin_transient';
		$data = get_transient( $name );
		if ( ! $data ) {
			$args = array(
				'timeout' => 30,
				'body'    => array(
					'item_ids'    => '242431',
					'product_key' => self::$thb_product_key,
				),
			);

			$request = wp_remote_get( self::$_instance->thb_dashboard_url( 'plugin/version' ), $args );

			$data = '';
			if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
				$data = json_decode( wp_remote_retrieve_body( $request ) );
			}
			set_transient( $name, $data, 6 * HOUR_IN_SECONDS );
		}
		return $data;
	}
	public function thb_check_for_update_theme( $transient ) {
		global $wp_filesystem;
		$args = array(
			'timeout' => 30,
			'body'    => array(
				'theme_name'  => self::$thb_theme_name,
				'product_key' => self::$thb_product_key,
			),
		);

		$request = wp_remote_get( self::$_instance->thb_dashboard_url( 'version' ), $args );

		if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
			$data = json_decode( wp_remote_retrieve_body( $request ) );
			update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', 0 );

			if ( isset( $data->success ) && $data->success == false ) {
				self::$thb_product_key_expired = 1;
				update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', 1 );
			} else {
				if ( version_compare( self::$thb_theme_version, $data->version, '<' ) ) {
					$transient->response[ self::$thb_theme_slug ] = array(
						'new_version' => $data->version,
						'package'     => $data->download_url,
						'url'         => 'http://fuelthemes.net',
					);

					update_option( 'thb_' . self::$thb_theme_slug . '_remote_ver', $data->version );
				}
			}
		}
		return $transient;
	}
	public function thb_upgradeFilter( $reply, $package, $updater ) {
		global $wp_filesystem;
		$cond = ( ! self::$thb_product_key || ( self::$thb_product_key_expired == 1 ) );

		if ( isset( $updater->skin->theme_info ) && $updater->skin->theme_info['Name'] == self::$thb_theme_name ) {
			if ( $cond ) {
				return new WP_Error( 'no_credentials', sprintf( __( 'To receive automatic updates, registration is required. Please visit <a href="%1$s" target="_blank">Product Registration</a> to activate your theme.', 'werkstatt' ), esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) ) );
			}
		}

		// VisualComposer
		if ( ( isset( $updater->skin->plugin ) ) && ( $updater->skin->plugin == 'js_composer/js_composer.php' ) ) {
			if ( $cond ) {
				return new WP_Error( 'no_credentials', sprintf( __( 'To receive automatic updates, registration is required. Please visit <a href="%1$s" target="_blank">Product Registration</a> to activate your theme.', 'werkstatt' ), esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) ) );
			}
		}
		return $reply;
	}
	public function thb_plugins_install( $item ) {
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$installed_plugins = get_plugins();

		$item['sanitized_plugin'] = $item['name'];

		// WordPress Repository
		if ( ! $item['version'] ) {
			$item['version'] = TGM_Plugin_Activation::$instance->does_plugin_have_update( $item['slug'] );
		}

		// Install Link
		if ( ! isset( $installed_plugins[ $item['file_path'] ] ) ) {
			$actions = array(
				'install' => sprintf(
					'<a href="%1$s" class="button" title="Install %2$s">Install Now</a>',
					esc_url(
						wp_nonce_url(
							add_query_arg(
								array(
									'page'          => urlencode( TGM_Plugin_Activation::$instance->menu ),
									'plugin'        => urlencode( $item['slug'] ),
									'plugin_name'   => urlencode( $item['sanitized_plugin'] ),
									'tgmpa-install' => 'install-plugin',
									'return_url'    => network_admin_url( 'admin.php?page=thb-plugins' ),
								),
								TGM_Plugin_Activation::$instance->get_tgmpa_url()
							),
							'tgmpa-install',
							'tgmpa-nonce'
						)
					),
					$item['sanitized_plugin']
				),
			);
		}
		// Activate Link
		elseif ( is_plugin_inactive( $item['file_path'] ) ) {
			$actions = array(
				'activate' => sprintf(
					'<a href="%1$s" class="button button-primary" title="Activate %2$s">Activate</a>',
					esc_url(
						add_query_arg(
							array(
								'plugin'             => urlencode( $item['slug'] ),
								'plugin_name'        => urlencode( $item['sanitized_plugin'] ),
								'thb-activate'       => 'activate-plugin',
								'thb-activate-nonce' => wp_create_nonce( 'thb-activate' ),
								'return_url'         => network_admin_url( 'admin.php?page=thb-plugins' ),
							),
							admin_url( 'admin.php?page=thb-plugins' )
						)
					),
					$item['sanitized_plugin']
				),
			);
		}
		// Update Link

		elseif ( version_compare( $installed_plugins[ $item['file_path'] ]['Version'], $item['version'], '<' ) ) {
			$actions = array(
				'update' => sprintf(
					'<a href="%1$s" class="button button-update" title="Install %2$s"><span class="dashicons dashicons-update"></span> Update</a>',
					wp_nonce_url(
						add_query_arg(
							array(
								'page'         => urlencode( TGM_Plugin_Activation::$instance->menu ),
								'plugin'       => urlencode( $item['slug'] ),
								'tgmpa-update' => 'update-plugin',
								'version'      => urlencode( $item['version'] ),
								'return_url'   => network_admin_url( 'admin.php?page=thb-plugins' ),
							),
							TGM_Plugin_Activation::$instance->get_tgmpa_url()
						),
						'tgmpa-update',
						'tgmpa-nonce'
					),
					$item['sanitized_plugin']
				),
			);
		} elseif ( self::$_instance->thb_ispluginactive( $item['file_path'] ) ) {
			$actions = array(
				'deactivate' => sprintf(
					'<a href="%1$s" class="button" title="Deactivate %2$s">Deactivate</a>',
					esc_url(
						add_query_arg(
							array(
								'plugin'               => urlencode( $item['slug'] ),
								'plugin_name'          => urlencode( $item['sanitized_plugin'] ),
								'thb-deactivate'       => 'deactivate-plugin',
								'thb-deactivate-nonce' => wp_create_nonce( 'thb-deactivate' ),
							),
							admin_url( 'admin.php?page=thb-plugins' )
						)
					),
					$item['sanitized_plugin']
				),
			);
		}

		return $actions;
	}
	public function thb_theme_admin_init() {
		$get_name = !empty($_GET['plugin_name']) ? sanitize_text_field( $_GET['plugin_name'] ) : '';

		if ( isset( $_GET['thb-deactivate'] ) && $_GET['thb-deactivate'] == 'deactivate-plugin' ) {

			check_admin_referer( 'thb-deactivate', 'thb-deactivate-nonce' );

			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			$plugins = get_plugins();

			foreach ( $plugins as $plugin_name => $plugin ) {
				if ( $plugin['Name'] == $get_name ) {
						deactivate_plugins( $plugin_name );
				}
			}
		}

		if ( isset( $_GET['thb-activate'] ) && $_GET['thb-activate'] == 'activate-plugin' ) {

			check_admin_referer( 'thb-activate', 'thb-activate-nonce' );

			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			$plugins = get_plugins();

			foreach ( $plugins as $plugin_name => $plugin ) {
				if ( $plugin['Name'] == $get_name ) {
					activate_plugin( $plugin_name );
				}
			}
		}

	}
	public function thb_activation_redirect() {
		if ( ! ( defined( 'WP_CLI' ) && WP_CLI ) ) {
			$werkstatt_installed = 'werkstatt_installed';

			if ( false == get_option( $werkstatt_installed, false ) ) {
				update_option( $werkstatt_installed, true );
				wp_redirect( admin_url( 'admin.php?page=thb-product-registration' ) );
				die();
			}

			delete_option( $werkstatt_installed );
		}
	}
	public function adminPageEnqueue() {
		wp_enqueue_script( 'thb-admin-meta', self::$thb_theme_directory_uri . 'assets/js/admin-meta.min.js', array( 'jquery' ), esc_attr( self::$thb_theme_version ) );
		wp_enqueue_style( 'thb-admin-css', self::$thb_theme_directory_uri . 'assets/css/admin.css', null, esc_attr( self::$thb_theme_version ) );
		wp_enqueue_style( 'thb-admin-vs-css', self::$thb_theme_directory_uri . 'assets/css/admin_vc.css', null, esc_attr( self::$thb_theme_version ) );

		if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
			wp_enqueue_style( 'vc_extra_css', self::$thb_theme_directory_uri . 'assets/css/vc_extra.css' );
			wp_enqueue_script( 'thb-admin-vc', self::$thb_theme_directory_uri . 'assets/js/admin-vc.min.js', array( 'jquery' ), esc_attr( self::$thb_theme_version ) );
		}
	}
	public function adminSetupMenu() {

		// Product Registration
		add_menu_page( self::$thb_theme_name, self::$thb_theme_name, 'edit_theme_options', 'thb-product-registration', array( & $this, 'thb_Product_Registration' ), self::$thb_theme_directory_uri . 'assets/img/admin/fuelthemes-icon.svg', 3 );

		// Product Registration
		add_submenu_page( 'thb-product-registration', 'Registration', 'Registration', 'edit_theme_options', 'thb-product-registration', array( & $this, 'thb_Product_Registration' ) );

		// Main Menu Item
		add_submenu_page( 'thb-product-registration', 'Plugins', 'Plugins', 'edit_theme_options', 'thb-plugins', array( & $this, 'thb_Plugins' ) );

		// Demo Import
		add_submenu_page( 'thb-product-registration', 'Demo Import', 'Demo Import', 'edit_theme_options', 'thb-demo-import', array( & $this, 'thb_Demo_Import' ) );

		// Theme Options
		add_submenu_page( 'thb-product-registration', 'Theme Options', 'Theme Options', 'edit_theme_options', 'thb-theme-options', '__return_false' );

	}
	public function thb_Plugins() {
		get_template_part( 'inc/admin/welcome/pages/plugins' );
	}
	public function thb_Product_Registration() {
		get_template_part( 'inc/admin/welcome/pages/registration' );
	}
	public function thb_Demo_Import() {
		get_template_part( 'inc/admin/welcome/pages/demo-import' );
	}
	public function thb_ispluginactive( $value ) {
		$func = 'is_plugin' . '_active';
		return $func( $value );
	}
	/**
	 *  Inintialize API
	 */
	public function thb_dashboard_url( $type = null ) {
		$url = 'https://my.fuelthemes.net';
		switch ( $type ) {
			case 'verify':
				$url .= '/api/verify';
				break;
			case 'verify-by-purchase':
				$url .= '/api/verify-by-purchase';
				break;
			case 'version':
				$url .= '/api/version';
				break;
			case 'plugin/version':
				$url .= '/api/plugin/version';
				break;
			case 'demo':
				$url .= '/api/demo';
				break;
		}
		return $url;
	}
}
// Main instance shortcut
function thb_Theme_Admin() {
	global $thb_Theme_Admin;
	return $thb_Theme_Admin;
}
Thb_Theme_Admin::instance();
