<?php
function thb_blog_posts() {
	check_ajax_referer( 'thb_blog_ajax', 'security' );
	$page       = filter_input( INPUT_POST, 'page', FILTER_VALIDATE_INT );
	$ppp        = get_option( 'posts_per_page' );
	$blog_style = ot_get_option( 'blog_style', 'style3' );

	$args = array(
		'posts_per_page' => $ppp,
		'paged'          => $page,
		'post_status'    => 'publish',
	);

	$more_query = new WP_Query( $args );

	add_filter( 'wp_get_attachment_image_attributes', 'thb_lazy_low_quality', 10, 3 );
	if ( $more_query->have_posts() ) :
		while ( $more_query->have_posts() ) :
			$more_query->the_post();
			get_template_part( 'inc/templates/postbit/' . $blog_style );
		endwhile;
	endif;
	wp_die();
}
add_action( 'wp_ajax_nopriv_thb_blog_ajax', 'thb_blog_posts' );
add_action( 'wp_ajax_thb_blog_ajax', 'thb_blog_posts' );

function thb_load_more() {
	check_ajax_referer( 'thb_ajax', 'security' );
	$i								= filter_input( INPUT_POST, 'i', FILTER_VALIDATE_INT );
	$aspect						= filter_input( INPUT_POST, 'aspect', FILTER_VALIDATE_BOOLEAN );
	$style						= !empty($_POST['style']) ? sanitize_text_field( $_POST['style'] ) : '';
	$columns					= !empty($_POST['columns']) ? sanitize_text_field( $_POST['columns'] ) : '';
	$masonry_layout		= !empty($_POST['masonry_layout']) ? sanitize_text_field( $_POST['masonry_layout'] ) : '';
	$loop							= !empty($_POST['loop']) ? sanitize_text_field( $_POST['loop'] ) : '';
	$page							= filter_input( INPUT_POST, 'page', FILTER_VALIDATE_INT );
	$hover_style			= !empty($_POST['hover_style']) ? sanitize_text_field( $_POST['hover_style'] ) : '';
	$title_position		= !empty($_POST['title_position']) ? sanitize_text_field( $_POST['title_position'] ) : '';
	$animation_style	= !empty($_POST['animation_style']) ? sanitize_text_field( $_POST['animation_style'] ) : '';

	$source_data          = VcLoopSettings::parseData( $loop );
	$source_data['paged'] = $page;
	$source_data          = thb_move_key_before( $source_data, 'offset', 'paged' );
	$query_builder        = new ThbLoopQueryBuilder( $source_data );
	$posts                = $query_builder->build();
	$posts                = $posts[1];

	add_filter( 'wp_get_attachment_image_attributes', 'thb_lazy_low_quality', 10, 3 );
	if ( $posts->have_posts() ) :
		while ( $posts->have_posts() ) :
			$posts->the_post();
			$size = ( 'style1' === $style && $masonry_layout ) ? thb_get_portfolio_size( $masonry_layout, $i ) : $columns;
			set_query_var( 'thb_masonry', $aspect );
			set_query_var( 'thb_size', $size );
			set_query_var( 'thb_hover_style', $hover_style );
			set_query_var( 'thb_title_position', $title_position );
			set_query_var( 'thb_animation', $animation_style );
			get_template_part( 'inc/templates/portfolio/' . $style );
			$i++;
		endwhile;
	endif;
	wp_die();
}
add_action( 'wp_ajax_nopriv_thb_ajax', 'thb_load_more' );
add_action( 'wp_ajax_thb_ajax', 'thb_load_more' );

function thb_posts_ajax() {
	check_ajax_referer( 'thb_posts_ajax', 'security' );
	$style		= !empty($_POST['style']) ? sanitize_text_field( $_POST['style'] ) : '';
	$columns	= !empty($_POST['columns']) ? sanitize_text_field( $_POST['columns'] ) : '';
	$loop			= !empty($_POST['loop']) ? sanitize_text_field( $_POST['loop'] ) : '';
	$page			= filter_input( INPUT_POST, 'page', FILTER_VALIDATE_INT );

	$source_data          = VcLoopSettings::parseData( $loop );
	$source_data['paged'] = $page;
	$query_builder        = new ThbLoopQueryBuilder( $source_data );
	$posts                = $query_builder->build();
	$more_query           = $posts[1];

	add_filter( 'wp_get_attachment_image_attributes', 'thb_lazy_low_quality', 10, 3 );
	if ( $more_query->have_posts() ) :
		while ( $more_query->have_posts() ) :
			$more_query->the_post();
			if ( 'style8' !== $style ) {
				set_query_var( 'columns', $columns );
				set_query_var( 'style2_size', '' );
				get_template_part( 'inc/templates/postbit/' . $style );
				set_query_var( 'style2-full', false );
			} elseif ( 'style8' === $style ) {
				set_query_var( 'columns', $columns );
				if ( 0 === $i ) {
					get_template_part( 'inc/templates/postbit/style8-first' );
				} else {
					get_template_part( 'inc/templates/postbit/style8' );
				}
			}
		endwhile;
	endif;
	wp_die();
}
add_action( 'wp_ajax_nopriv_thb_posts_ajax', 'thb_posts_ajax' );
add_action( 'wp_ajax_thb_posts_ajax', 'thb_posts_ajax' );
